package com.hp.user.service.controller;

import com.hp.user.client.entity.*;
import com.hp.user.client.service.AuditService;
import com.hp.user.client.service.CustomerCompanyService;
import com.hp.user.client.service.CustomerServiceProviderEnterpriseService;
import com.hp.user.service.entity.CustomerServiceProviderEnterprise;
import com.hp.user.service.utils.HttpResult;
import com.hp.user.service.utils.IdWorker;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Api(tags = "企业/服务商API接口")
@RestController
@RequestMapping("/company")
public class CompanyController {
    @Autowired
    private CustomerCompanyService customerCompanyService;
    @Autowired
    private AuditService auditService;
    @Autowired
    private CustomerServiceProviderEnterpriseService csService;

    /**
     * 添加企业/服务商
     *
     * @param company 企业/服务商信息
     * @return HttpResult
     */
    @ApiOperation(value = "新增企业/服务商", notes = "提示：要指定审核状态 status；服务商type=0，企业type=1；若新增企业，则需要填serviceProviderIds", httpMethod = "POST")
    @PostMapping("/addCompany")
    @Transactional
    public HttpResult addCompany(@RequestBody CustomerCompanyVO company, @RequestParam String serviceProviderId) {
        company.setCustomerId(IdWorker.generactorId().toString());
        boolean flag1 = true, flag2 = true;
        flag1 = customerCompanyService.insert(company);
        if (serviceProviderId != null) {
            CustomerServiceProviderEnterpriseVO temp = new CustomerServiceProviderEnterpriseVO(IdWorker.generactorId().toString(), serviceProviderId, company.getCustomerId());
            flag2 = csService.insert(temp);
        }
        if (flag1 && flag2) return HttpResult.success(company.getCustomerId());
        else return HttpResult.fail("添加失败");
    }
//    public HttpResult addCompany(@RequestBody CustomerCompanyVO company, @RequestBody List<String> serviceProviderIds) {
//        company.setCustomerId(IdWorker.generactorId().toString());
//        boolean flag1 = true, flag2 = true;
//        flag1 = customerCompanyService.insert(company);
//        if (serviceProviderIds != null) {
//            List<CustomerServiceProviderEnterpriseVO> csList=new ArrayList<>();
//            CustomerServiceProviderEnterpriseVO temp;
//            for(String serviceProviderId:serviceProviderIds){
//                temp = new CustomerServiceProviderEnterpriseVO(IdWorker.generactorId().toString(), serviceProviderId, company.getCustomerId());
//                csList.add(temp);
//            }
//            flag2=csService.insertBatch(csList);
//        }
//        if (flag1 && flag2) return HttpResult.success(company.getCustomerId());
//        else return HttpResult.fail("添加失败");
//    }

    /**
     * 更新企业/服务商信息
     *
     * @param company 企业/服务商信息
     * @return HttpResult
     */
    @ApiOperation(value = "更新企业/服务商信息", notes = "若更新企业，则需要填serviceProviderId")
    @PostMapping("/updateCompany")
    @Transactional
    public HttpResult updateCompany(@RequestBody CustomerCompanyVO company, @RequestParam String serviceProviderId) {
        boolean flag1 = true, flag2 = true;
        flag1 = customerCompanyService.update(company);
        if (serviceProviderId != null) {
            CustomerServiceProviderEnterpriseVO cs = csService.queryCsByCompanyIdAndServiceProviderId(company.getCustomerId(), serviceProviderId);
            cs.setServiceProviderId(serviceProviderId);
            flag2 = csService.update(cs);
        }
        if (flag1 && flag2) return HttpResult.success();
        else return HttpResult.fail("更新失败");
    }

    /**
     * 根据企业Id删除企业
     *
     * @param companyId 企业Id
     * @return HttpResult
     */
    @ApiOperation(value = "删除企业/服务商", notes = "若删除企业，则需要填serviceProviderId")
    @GetMapping("/deleteCompanyByCompanyId")
    public HttpResult deleteCompanyByCompanyId(@RequestParam String companyId, @RequestParam String serviceProviderId) {
        boolean flag1 = true, flag2 = true;
        flag1 = customerCompanyService.delete(companyId);
        if (serviceProviderId != null) {
            CustomerServiceProviderEnterpriseVO cs = csService.queryCsByCompanyIdAndServiceProviderId(companyId, serviceProviderId);
            flag2 = csService.delete(cs.getId());
        }
        if (flag1 && flag2) return HttpResult.success();
        else return HttpResult.fail("删除失败");
    }

    /**
     * 根据企业Id查询某企业信息
     *
     * @param companyId 企业Id
     * @return HttpResult
     */
    @ApiOperation(value = "根据企业/服务商Id 查询某企业/服务商信息", notes = "服务商type为0，企业type为1")
    @GetMapping("/queryCompanyByCompanyId")
    public HttpResult queryCompanyByCompanyId(@RequestParam String companyId, @RequestParam Integer type) {
        CustomerCompanyVO companyVO = customerCompanyService.queryCompanyByCompanyId(companyId);
        if(type==1){
            companyVO.setServiceProviderId(csService.queryServiceProviderIdByCompanyId(companyId));
        }
        if (companyVO != null) return HttpResult.success(companyVO);
        else return HttpResult.fail("查询失败/已被删除");
    }

//    /**
//     * 分页查询所有企业信息
//     *
//     * @param current 要查询页数
//     * @param size    一页的行数
//     * @return HttpResult
//     */
//    @ApiOperation(value = "分页查询所有企业/服务商", notes = "输入的current为要查询的页数，size为一页的行数，返回的total为总行数，服务商type为0，企业type为1")
//    @GetMapping("/queryAllCompanyByPage")
//    public HttpResult queryAllCompanyByPage(@RequestParam Long current, @RequestParam Integer size, @RequestParam Integer type) {
//        CompanyPage companyPage = customerCompanyService.getCompanysPage(current, size, type);
//        if (companyPage != null) return HttpResult.success(companyPage);
//        else return HttpResult.fail("查询失败");
//    }

    /**
     * 根据服务商姓名分页查询服务商
     *
     * @param name    服务商名称
     * @param current 要查询页数
     * @param size    一页的行数
     * @return HttpResult
     */
    @ApiOperation(value = "根据服务商姓名分页查询服务商")
    @GetMapping("/queryServiceProvidersPageByName")
    public HttpResult queryServiceProvidersPageByName(String name, @RequestParam Long current, @RequestParam Integer size) {
        CompanyPage companyPage = customerCompanyService.queryServiceProvidersByName(name, current, size);
        if (companyPage != null) return HttpResult.success(companyPage);
        else return HttpResult.fail("查询失败");
    }

    /**
     * 分页查询符合条件的企业信息
     *
     * @param name                企业名称
     * @param serviceProviderName 企业关联服务商名称
     * @param status              审核状态
     * @param current             要查询页数
     * @param size                一页的行数
     * @return HttpResult
     */
    @ApiOperation(value = "根据企业姓名、关联服务商、审核状态分页查询企业", notes = "审核状态\"全部\"则status=0")
    @GetMapping("/queryCompanysPageByNameAndServiceProviderAndStatus")
    public HttpResult queryCompanysPageByNameAndServiceProviderAndStatus(String name, String serviceProviderName, @RequestParam Integer status, @RequestParam Long current, @RequestParam Integer size) {
        CompanyPage companyPage = customerCompanyService.queryCompanysPageByNameAndServiceAndStatus(name, serviceProviderName, status, current, size);
        if (companyPage != null) return HttpResult.success(companyPage);
        else return HttpResult.fail("查询失败");
    }

    /**
     * 微信端，成为合同用户
     *
     * @param company 企业信息
     * @param willing 是否有意向成为合同用户
     * @return HttpResult
     */
    @ApiOperation(value = "成为合同用户", notes = "添加成功会返回添加的企业Id")
    @PostMapping("/becomeContractUser")
    @Transactional
    public HttpResult becomeContractUser(@RequestBody CustomerCompanyVO company, @RequestBody boolean willing) {
        company.setCustomerId(IdWorker.generactorId().toString());
        company.setType((short) 1); // 企业
        company.setStatus((short) 1); // 未审核
        AuditVO audit = new AuditVO();
        audit.setAuditId(IdWorker.generactorId().toString());
        audit.setUserId(company.getCustomerId());
        audit.setStatus((short) 1); // 未审核
        audit.setSource((short) 1); // 来源：维信
        // 愿意成为合同用户
        if (willing) audit.setVipLevel((short) 1); // 普通会员
        else audit.setVipLevel((short) 2); // 意向用户
        boolean flag1 = customerCompanyService.insert(company);
        boolean flag2 = auditService.insert(audit);
        if (flag1 && flag2) return HttpResult.success(company.getCustomerId());
        else return HttpResult.fail("添加失败");
    }

    /**
     * 分页查询所有认证企业
     *
     * @param current 要查询页数
     * @param size    一页的行数
     * @return HttpResult
     */
    @ApiOperation(value = "分页查询所有认证企业", notes = "输入的current为要查询的页数，size为一页的行数，返回的total为总行数")
    @GetMapping("/queryAllCompanyCertifyPage")
    public HttpResult queryAllCompanyCertifyPage(@RequestParam Long current, @RequestParam Integer size) {
        CompanyAuditPage companyAuditPage = customerCompanyService.getCompanyAuditsPage(current, size);
        if (companyAuditPage != null) return HttpResult.success(companyAuditPage);
        else return HttpResult.fail("查询失败");
    }

    /**
     * 根据企业姓名、审核状态、提交时间分页查询认证企业
     *
     * @param name      企业名称
     * @param status    审核状态
     * @param startTime 提交时间的开始间隔
     * @param endTime   提交时间的结束间隔
     * @param current   要查询的页数
     * @param size      一页的行数
     * @return HttpResult
     */
    @ApiOperation(value = "根据企业姓名、审核状态、提交时间分页查询认证企业", notes = "若审核状态为全部，则status填0")
    @GetMapping("/queryCompanysPageByNameAndStatusAndCreateTime")
    public HttpResult queryCompanysPageByNameAndStatusAndCreateTime(String name, @RequestParam Integer status, Date startTime, Date endTime, @RequestParam Long current, @RequestParam Integer size) {
        CompanyAuditPage companyAuditPage = customerCompanyService.queryCompanysPageByNameAndStatusAndCreateTime(name, status, startTime, endTime, current, size);
        if (companyAuditPage != null) return HttpResult.success(companyAuditPage);
        else return HttpResult.fail("查询失败");
    }

//    public HttpResult queryContectUserByBusinessContectAndPhone

//    /**
//     * 查询某企业的所有用户
//     * @param companyId 企业Id
//     */
//    @GetMapping("/queryAllUserOfCompany")
//    public void queryAllUserOfCompany(String companyId){
//
//    }
//
//    /**
//     * 关联某企业与某用户
//     * @param companyId 企业Id
//     * @param userId 用户Id
//     */
//    @GetMapping("/associateCompanyAndUser")
//    public void associateCompanyAndUser(String companyId,String userId){
//
//    }
//
//    /**
//     * 解除某企业与某用户的关联
//     * @param companyId 企业Id
//     * @param userId 用户Id
//     */
//    @GetMapping("/dissociateCompanyAndUser")
//    public void dissociateCompanyAndUser(String companyId,String userId){
//
//    }
}
