package com.hp.user.service.controller;

import com.hp.user.client.entity.StationPage;
import com.hp.user.client.entity.StationVO;
import com.hp.user.client.service.StationService;
import com.hp.user.service.utils.HttpResult;
import com.hp.user.service.utils.IdWorker;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@Api(tags = "站点API接口")
@RestController
@RequestMapping("/station")
public class StationController {
    @Autowired
    private StationService stationService;

    /**
     * 添加站点
     *
     * @param station 站点信息
     * @return HttpResult
     */
    @ApiOperation(value = "新增站点")
    @PostMapping("/addStation")
    public HttpResult addStation(@RequestBody StationVO station) {
        station.setStationId(IdWorker.generactorId().toString());
        boolean flag = stationService.insert(station);
        if (flag) return HttpResult.success(station.getStationId());
        else return HttpResult.fail("添加失败");
    }

    /**
     * 更新站点信息
     *
     * @param station 站点信息
     * @return HttpResult
     */
    @ApiOperation(value = "更新站点信息")
    @PostMapping("/updateStation")
    public HttpResult updateStation(@RequestBody StationVO station) {
        boolean flag = stationService.update(station);
        if (flag) return HttpResult.success();
        else return HttpResult.fail("更新失败");
    }

    /**
     * 根据站点Id删除站点
     *
     * @param stationId 站点Id
     * @return HttpResult
     */
    @ApiOperation(value = "删除站点")
    @GetMapping("/deleteStationByStationId")
    public HttpResult deleteStationByStationId(@RequestParam String stationId) {
        boolean flag = stationService.delete(stationId);
        if (flag) return HttpResult.success();
        else return HttpResult.fail("删除失败");
    }

    /**
     * 根据站点Id查询某站点信息
     *
     * @param stationId 站点Id
     * @return HttpResult
     */
    @ApiOperation(value = "根据站点Id查询某站点")
    @GetMapping("/queryStationByStationId")
    public HttpResult queryStationByStationId(String stationId) {
        StationVO stationVO = stationService.queryStationByStationId(stationId);
        if (stationVO != null) return HttpResult.success(stationVO);
        else return HttpResult.fail("查询失败/该站点已被删除");
    }

    /**
     * 根据站点名称查询某站点信息
     *
     * @param stationName 站点名称
     * @return HttpResult
     */
    @ApiOperation(value = "根据站点名称查询某站点")
    @GetMapping("/queryStationByStationName")
    public HttpResult queryStationByStationName(String stationName) {
        StationVO stationVO = stationService.queryStationByStationName(stationName);
        if (stationVO != null) return HttpResult.success(stationVO);
        else return HttpResult.fail("查询失败");
    }

    /**
     * 查询所有站点信息
     */
    /**
     * 分页查询所有站点信息
     *
     * @param current 要查询页数
     * @param size    一页的行数
     * @return HttpResult
     */
    @ApiOperation(value = "分页查询所有站点", notes = "输入的current为要查询的页数，size为一页的行数，返回的total为总行数")
    @GetMapping("/queryAllStationByPage")
    public HttpResult queryAllStationByPage(@RequestParam Long current, @RequestParam Integer size) {
        StationPage stationPage = stationService.getStationsPage(current, size);
        if (stationPage != null) return HttpResult.success(stationPage);
        else return HttpResult.fail("查询失败");
    }
}
