package com.hp.user.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.toolkit.SqlHelper;
import com.hp.user.client.entity.AccountPage;
import com.hp.user.client.entity.AccountVO;
import com.hp.user.client.entity.DataResult;
import com.hp.user.client.service.AccountService;
import com.hp.user.client.service.MessageService;
import com.hp.user.service.constants.UserConstants;
import com.hp.user.service.dao.AccountMapper;
import com.hp.user.service.entity.Account;
import com.hp.user.service.utils.WeixinSignUtil;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang3.StringUtils;
//import com.hp.user.service.utils.IdWorker;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * <p>
 * 用户信息表 服务实现类
 * </p>
 *
 * @author 王怡静
 * @since 2020-11-20
 */
@Service
public class AccountServiceImpl implements AccountService {
	
	@Autowired
	private MessageService messageService;
	
	@Autowired
	private AccountMapper accountMapper;

	@Override
	public void login(String phone, String verificationCode) {
		try {
			//需要判断phone是否存在
			checkPhone(phone);
			String code = messageService.getVerificationCode(phone);
			if(StringUtils.equals(verificationCode, code)) {
				//登陆成功
			}else {
				//登陆失败
				//返回错误信息
			}
		}catch(Exception e) {
			
		}
	}

	@Override
	public Boolean checkPhone(String phone) {
		//不存在为true
		Boolean flage = true;
		try {
			
			QueryWrapper<Account> queryWrapper = new QueryWrapper<>();
			queryWrapper.eq("phone", phone);
			queryWrapper.eq("sys_deleted", 0);
			Integer count = accountMapper.selectCount(queryWrapper);
			if(count>0) {
				//表示手机以及存在，需要返回错误
				System.out.println("手机号已经存在");
				flage = false;
			}
			
		}catch(Exception e) {
			
		}
		return flage;
		
	}

	@Override
	public void register(AccountVO accountVo) {
		try {
			if(checkPhone(accountVo.getPhone())) {
				Account account = new Account();
				BeanUtils.copyProperties(accountVo, account);
				Long id = IdWorker.getId();
				account.setUserId(id.toString());
				accountMapper.insert(account);
			}
		}catch(Exception e) {
			
		}
		
	}

	@Override
	public void bindWx(String userIdStr, String wxNumber) {
		try {
//			Long userId = Long.parseLong(userIdStr);
			Account account = new Account();
			account.setUserId(userIdStr);
			account.setWxNumber(wxNumber);
			account.setWxNumber(wxNumber);
			accountMapper.updateById(account);
		}catch(Exception e) {
			
		}
		
	}

	@Override
	public DataResult<AccountVO> wxAuthorization(AccountVO account,String wxCode) {
		DataResult<AccountVO> result = new DataResult<AccountVO>();
		JSONObject data = null;
		try {
	        data = WeixinSignUtil.getCode2Session(wxCode);
	        String errmsg = data.getString("errmsg");
	        if(null != errmsg) {
	        	result.setCode("-1");
	        	result.setCode(errmsg);
	        	return result;
	        }
	        String openid = data.getString("openid");
	        QueryWrapper<Account> queryWrapper = new QueryWrapper<>();
			queryWrapper.eq("wx_opean_id", openid);
			Account findAccount = accountMapper.selectOne(queryWrapper);
			BeanUtils.copyProperties(findAccount, account);
			if(null != findAccount) {
				result.setCode("-1");
	        	result.setMessage("微信需要绑定");
			}else {
				result.setData(account);
			}
	        
		}catch(Exception e) {
			result.setCode("-1");
        	result.setMessage("系统出现问题");
		}
		return result;
		
	}

	@Override
	public DataResult<AccountVO> wxRegister(AccountVO accountVO, String verificationCode) {
		DataResult<AccountVO> result = new DataResult<AccountVO>();
		try {
			if(StringUtils.isBlank(accountVO.getPhone())) {
				if(checkPhone(accountVO.getPhone())) {
					
					String code = messageService.getVerificationCode(accountVO.getPhone());
					if(StringUtils.equals(verificationCode, code)) {
					}
					Account account = new Account();
					BeanUtils.copyProperties(accountVO, account);
					Long id = IdWorker.getId();
					account.setUserId(id.toString());
					accountMapper.insert(account);
					BeanUtils.copyProperties(account, accountVO);
					result.setData(accountVO);
				}else {
					result.setCode("-1");
		        	result.setMessage("手机号码已经存在");
					return result;
				}
			}else {
				result.setCode("-1");
	        	result.setMessage("手机号不能为空");
				return result;
			}
			
		}catch(Exception e) {
			
		}
		return result;
	}


	@Override
	public boolean insert(AccountVO account) {
		Account temp = new Account();
		BeanUtils.copyProperties(account,temp);
		return SqlHelper.retBool(accountMapper.insert(temp));
	}

	@Override
	public boolean delete(String userId) {
		Account temp = accountMapper.selectById(userId);
		temp.setSysDeleted((short)1);
		return SqlHelper.retBool(accountMapper.updateById(temp));
	}

	@Override
	public boolean update(AccountVO account) {
		Account temp = new Account();
		BeanUtils.copyProperties(account,temp);
		return SqlHelper.retBool(accountMapper.updateById(temp));
	}

	@Override
	public AccountPage queryAccountsPageByCompanyIdAndUserNameAndPhoneAndStatus(String companyId, String userName, String phone, Integer status, Long current, Integer size) {
		AccountPage accountPage = new AccountPage();
		IPage<Account> page = new Page<>(current,size);
		QueryWrapper<Account> wrapper = new QueryWrapper<>();
		wrapper.eq("company_id",companyId);
		wrapper.orderByDesc("sys_create_time");
		if(userName!=null) wrapper.like("user_name",userName);
		if(phone!=null) wrapper.like("phone",phone);
		if(status==0|| status==1) wrapper.eq("status",status);
		accountMapper.selectPage(page,wrapper);
		List<Account> accounts = page.getRecords();
		List<AccountVO> accountVOs = new ArrayList<>();
		AccountVO temp;
		for(Account account:accounts){
			temp = new AccountVO();
			BeanUtils.copyProperties(account,temp);
			accountVOs.add(temp);
		}
		accountPage.setAccountList(accountVOs);
		accountPage.setTotal(page.getTotal());
		accountPage.setCurrent(current);
		accountPage.setSize(size);
		return accountPage;
	}

	@Override
	public boolean batchChangeStatusOfUser(String companyId,String[] userIds,Short status){
		Account account;
		for(String userId:userIds){
			account = accountMapper.selectById(userId);
			account.setStatus(status);
			if(!SqlHelper.retBool(accountMapper.updateById(account))) return false;
		}
		return true;
	}
}
